<?php

/* Copyright (c) 1998-2010 ILIAS open source, Extended GPL, see docs/LICENSE */

require_once './Modules/Exercise/classes/class.ilExAssignmentEditorGUI.php';

/**
* Class ilExAssignmentEditorGUIOverride
*/
class ilExAssignmentEditorGUIOverride extends ilExAssignmentEditorGUI
{
    public function getTextAssignmentCreationForm()
    {
        return $this->initAssignmentForm(5, 'create');
    }

    public function getTextAssignmentUpdateForm()
    {
        $form = $this->initAssignmentForm(5, 'edit');
        $this->getAssignmentValues($form);

        require_once './Customizing/global/plugins/Services/UIComponent/UserInterfaceHook/PlagScanExercise/classes/class.ilPlagScanAssignmentConfigPersistence.php';
        $persistence = new ilPlagScanAssignmentConfigPersistence($GLOBALS['DIC']->database());
        $settings = $persistence->getByAssignmentId(ilUtil::stripSlashes($_GET['ass_id']));
        $form->getItemByPostVar('psx_activation')->setChecked($settings->getActivation());
        $form->getItemByPostVar('psx_checkstart')->setValue($settings->getStartCheck());
        $form->getItemByPostVar('psx_resultshare')->setValue($settings->getShareSetting());
        $form->getItemByPostVar('psx_resulttype')->setValue($settings->getShareType());

        return $form;
    }

    public function getUploadAssignmentCreationForm()
    {
        return $this->initAssignmentForm(1, 'create');
    }

    public function getUploadAssignmentUpdateForm()
    {
        $form = $this->initAssignmentForm(1, 'edit');
        $this->getAssignmentValues($form);

        require_once './Customizing/global/plugins/Services/UIComponent/UserInterfaceHook/PlagScanExercise/classes/class.ilPlagScanAssignmentConfigPersistence.php';
        $persistence = new ilPlagScanAssignmentConfigPersistence($GLOBALS['DIC']->database());
        $settings = $persistence->getByAssignmentId(ilUtil::stripSlashes($_GET['ass_id']));
        $form->getItemByPostVar('psx_activation')->setChecked($settings->getActivation());
        $form->getItemByPostVar('psx_checkstart')->setValue($settings->getStartCheck());
        $form->getItemByPostVar('psx_resultshare')->setValue($settings->getShareSetting());
        $form->getItemByPostVar('psx_resulttype')->setValue($settings->getShareType());

        return $form;
    }

	/**
	* Init assignment form.
	*
	* @param int $a_type
	* @param int $a_mode "create"/"edit"
	*/
	protected function initAssignmentForm($a_type, $a_mode = "create")
	{
		$lng = $this->lng;
		$ilCtrl = $this->ctrl;

		$ass_type = $this->types->getById($a_type);
		$ass_type_gui = $this->type_guis->getById($a_type);
		$ilCtrl->setParameter($this->parent, "ass_type", $a_type);
		
		$lng->loadLanguageModule("form");
		include_once("./Services/Form/classes/class.ilPropertyFormGUI.php");
		$form = new ilPropertyFormGUI();
		if ($a_mode == "edit")
		{
			$form->setTitle($lng->txt("exc_edit_assignment"));
		}
		else
		{
			$form->setTitle($lng->txt("exc_new_assignment"));
		}
		$form->setFormAction($ilCtrl->getFormAction($this->parent));

		// title
		$ti = new ilTextInputGUI($lng->txt("title"), "title");
		$ti->setMaxLength(200);
		$ti->setRequired(true);
		$form->addItem($ti);

		// type
		$ty = $this->getTypeDropdown();
		$ty->setValue($a_type);
		$ty->setDisabled(true);
		$form->addItem($ty);

		//
		// type specific start
		//

		$ass_type_gui->addEditFormCustomProperties($form);

		//
		// type specific end
		//

		if($ass_type->usesTeams())
		{
			if($a_mode == "edit") {
				$has_teams = (bool)count(ilExAssignmentTeam::getAssignmentTeamMap($this->assignment->getId()));
			} else {
				$has_teams = false;
			}

			// Radio for creators
			$rd_team = new ilRadioGroupInputGUI($lng->txt("exc_team_formation"), "team_creator");

			$radio_participants = new ilRadioOption(
				$lng->txt("exc_team_by_participants"),
				ilExAssignment::TEAMS_FORMED_BY_PARTICIPANTS,
				$lng->txt("exc_team_by_participants_info")
			);

			$radio_tutors = new ilRadioOption(
				$lng->txt("exc_team_by_tutors"),
				ilExAssignment::TEAMS_FORMED_BY_TUTOR,
				$lng->txt("exc_team_by_tutors_info")
			);

			#23679
			if(!$has_teams)
			{
				// Creation options
				$rd_creation_method = new ilRadioGroupInputGUI($lng->txt("exc_team_creation"), "team_creation");
				$rd_creation_method->setRequired(true);

				//manual
				$rd_creation_manual = new ilRadioOption(
					$lng->txt("exc_team_by_tutors_manual"),
					0,
					$lng->txt("exc_team_by_tutors_manual_info")
				);
				$rd_creation_method->addOption($rd_creation_manual);

				//random options
				$rd_creation_random = new ilRadioOption(
					$lng->txt("exc_team_by_random"),
					ilExAssignment::TEAMS_FORMED_BY_RANDOM,
						$lng->txt("exc_team_by_random_info")."<br>".$lng->txt("exc_total_members").": ".$this->getExerciseTotalMembers()
				);
				$rd_creation_method->addOption($rd_creation_random);

				$number_teams = new ilNumberInputGUI($lng->txt("exc_num_teams"), "number_teams");
				$number_teams->setSize(3);
				$number_teams->setMinValue(1);
				$number_teams->setMaxValue($this->getExerciseTotalMembers());
				$number_teams->setRequired(true);
				$number_teams->setSuffix($lng->txt("exc_team_assignment_adopt_teams"));
				$rd_creation_random->addSubItem($number_teams);

				$min_team_participants = new ilNumberInputGUI($lng->txt("exc_min_team_participants"), "min_participants_team");
				$min_team_participants->setSize(3);
				$min_team_participants->setMinValue(1);
				$min_team_participants->setMaxValue($this->getExerciseTotalMembers());
				$min_team_participants->setRequired(true);
				$min_team_participants->setSuffix($lng->txt("exc_participants"));
				$rd_creation_random->addSubItem($min_team_participants);

				$max_team_participants = new ilNumberInputGUI($lng->txt("exc_max_team_participants"), "max_participants_team");
				$max_team_participants->setSize(3);
				$max_team_participants->setMinValue(1);
				$max_team_participants->setMaxValue($this->getExerciseTotalMembers());
				$max_team_participants->setRequired(true);
				$max_team_participants->setSuffix($lng->txt("exc_participants"));
				$rd_creation_random->addSubItem($max_team_participants);

				$options = ilExAssignmentTeam::getAdoptableTeamAssignments($this->exercise_id);
				if(count($options))
				{
					$radio_assignment = new ilRadioOption(
						$lng->txt("exc_team_by_assignment"),
						ilExAssignment::TEAMS_FORMED_BY_ASSIGNMENT,
						$lng->txt("exc_team_by_assignment_info")
					);

					$radio_assignment_adopt = new ilRadioGroupInputGUI($lng->txt("exc_assignment"), "ass_adpt");
					$radio_assignment_adopt->setRequired(true);
					$radio_assignment_adopt->addOption(new ilRadioOption($lng->txt("exc_team_assignment_adopt_none"), -1));

					foreach($options as $id => $item)
					{
						$option = new ilRadioOption($item["title"], $id);
						$option->setInfo($lng->txt("exc_team_assignment_adopt_teams").": ".$item["teams"]);
						$radio_assignment_adopt->addOption($option);
					}
					$radio_assignment->addSubItem($radio_assignment_adopt);
					$rd_creation_method->addOption($radio_assignment);
				}

				$radio_tutors->addSubItem($rd_creation_method);
			}
			$rd_team->addOption($radio_participants);
			$rd_team->addOption($radio_tutors);
			/*if(!$has_teams) {
				$rd_team->addOption($radio_assignment);
			}*/
			$form->addItem($rd_team);

			if($has_teams)
			{
				$rd_team->setDisabled(true);
			}
		}

		// mandatory
		$cb = new ilCheckboxInputGUI($lng->txt("exc_mandatory"), "mandatory");
		$cb->setInfo($lng->txt("exc_mandatory_info"));
		$cb->setChecked(true);
		$form->addItem($cb);

		// Work Instructions
		$sub_header = new ilFormSectionHeaderGUI();
		$sub_header->setTitle($lng->txt("exc_work_instructions"), "work_instructions");
		$form->addItem($sub_header);

		$desc_input = new ilTextAreaInputGUI($lng->txt("exc_instruction"), "instruction");
		$desc_input->setRows(20);
		$desc_input->setUseRte(true);
		$desc_input->setRteTagSet("mini");
		$form->addItem($desc_input);

		// files
		if ($a_mode == "create")
		{
			$files = new ilFileWizardInputGUI($lng->txt('objs_file'),'files');
			$files->setFilenames(array(0 => ''));
			$form->addItem($files);
		}

		// Schedule
		$sub_header = new ilFormSectionHeaderGUI();
		$sub_header->setTitle($lng->txt("exc_schedule"), "schedule");
		$form->addItem($sub_header);

		// start time
		$start_date = new ilDateTimeInputGUI($lng->txt("exc_start_time"), "start_time");
		$start_date->setShowTime(true);
		$form->addItem($start_date);

		// Deadline Mode
		$radg = new ilRadioGroupInputGUI($lng->txt("exc_deadline"), "deadline_mode");
		$radg->setValue(0);
		$op1 = new ilRadioOption($lng->txt("exc_fixed_date"), 0, $lng->txt("exc_fixed_date_info"));
		$radg->addOption($op1);
		$op2 = new ilRadioOption($lng->txt("exc_relative_date"), 1, $lng->txt("exc_relative_date_info"));
		$radg->addOption($op2);
		$form->addItem($radg);

		// Deadline fixed date
		$deadline = new ilDateTimeInputGUI($lng->txt("date"), "deadline");
		$deadline->setShowTime(true);
		$op1->addSubItem($deadline);
		
		// extended Deadline
		$deadline2 = new ilDateTimeInputGUI($lng->txt("exc_deadline_extended"), "deadline2");				
		$deadline2->setInfo($lng->txt("exc_deadline_extended_info"));
		$deadline2->setShowTime(true);
		$deadline->addSubItem($deadline2);


		// submit reminder
		$rmd_submit = new ilCheckboxInputGUI($this->lng->txt("exc_reminder_submit_setting"), "rmd_submit_status");

		$rmd_submit_start = new ilNumberInputGUI($this->lng->txt("exc_reminder_start"), "rmd_submit_start");
		$rmd_submit_start->setSize(3);
		$rmd_submit_start->setMaxLength(3);
		$rmd_submit_start->setSuffix($lng->txt('days'));
		$rmd_submit_start->setInfo($this->lng->txt("exc_reminder_start_info"));
		$rmd_submit_start->setRequired(true);
		$rmd_submit_start->setMinValue(1);
		$rmd_submit->addSubItem($rmd_submit_start);

		$rmd_submit_frequency = new ilNumberInputGUI($this->lng->txt("exc_reminder_frequency"), "rmd_submit_freq");
		$rmd_submit_frequency->setSize(3);
		$rmd_submit_frequency->setMaxLength(3);
		$rmd_submit_frequency->setSuffix($lng->txt('days'));
		$rmd_submit_frequency->setRequired(true);
		$rmd_submit_frequency->setMinValue(1);
		$rmd_submit->addSubItem($rmd_submit_frequency);

		$rmd_submit_end = new ilDateTimeInputGUI($lng->txt("exc_reminder_end"), "rmd_submit_end");
		$rmd_submit_end->setRequired(true);
		$rmd_submit->addSubItem($rmd_submit_end);

		$rmd_submit->addSubItem($this->addMailTemplatesRadio(ilExAssignmentReminder::SUBMIT_REMINDER));

		// grade reminder
		$rmd_grade = new ilCheckboxInputGUI($this->lng->txt("exc_reminder_grade_setting"), "rmd_grade_status");

		$rmd_grade_frequency = new ilNumberInputGUI($this->lng->txt("exc_reminder_frequency"), "rmd_grade_freq");
		$rmd_grade_frequency->setSize(3);
		$rmd_grade_frequency->setMaxLength(3);
		$rmd_grade_frequency->setSuffix($lng->txt('days'));
		$rmd_grade_frequency->setRequired(true);
		$rmd_grade_frequency->setMinValue(1);
		$rmd_grade->addSubItem($rmd_grade_frequency);

		$rmd_grade_end = new ilDateTimeInputGUI($lng->txt("exc_reminder_end"), "rmd_grade_end");
		$rmd_grade_end->setRequired(true);
		$rmd_grade->addSubItem($rmd_grade_end);

		$rmd_grade->addSubItem($this->addMailTemplatesRadio(ilExAssignmentReminder::GRADE_REMINDER));

		$form->addItem($rmd_submit);
		$form->addItem($rmd_grade);

		// relative deadline
		$ti = new ilNumberInputGUI($lng->txt("days"), "relative_deadline");
		$ti->setMaxLength(3);
		$ti->setSize(3);
		$op2->addSubItem($ti);
		

		// max number of files
		if($ass_type->usesFileUpload())
		{
			$sub_header = new ilFormSectionHeaderGUI();
			$sub_header->setTitle($ass_type->getTitle());
			$form->addItem($sub_header);
			$max_file_tgl = new ilCheckboxInputGUI($lng->txt("exc_max_file_tgl"), "max_file_tgl");
			$form->addItem($max_file_tgl);

			$max_file = new ilNumberInputGUI($lng->txt("exc_max_file"), "max_file");
			$max_file->setInfo($lng->txt("exc_max_file_info"));
			$max_file->setRequired(true);
			$max_file->setSize(3);
			$max_file->setMinValue(1);
			$max_file_tgl->addSubItem($max_file);
		}

		// after submission
		$sub_header = new ilFormSectionHeaderGUI();
		$sub_header->setTitle($lng->txt("exc_after_submission"), "after_submission");
		$form->addItem($sub_header);
		if (!$ass_type->usesTeams())
		{
			// peer review
			$peer = new ilCheckboxInputGUI($lng->txt("exc_peer_review"), "peer");		
			$peer->setInfo($lng->txt("exc_peer_review_ass_setting_info"));
			$form->addItem($peer);
		}
		
		
		// global feedback
		
		$fb = new ilCheckboxInputGUI($lng->txt("exc_global_feedback_file"), "fb");				
		$form->addItem($fb);
		
			$fb_file = new ilFileInputGUI($lng->txt("file"), "fb_file");
			$fb_file->setRequired(true); // will be disabled on update if file exists - see getAssignmentValues()
			// $fb_file->setAllowDeletion(true); makes no sense if required (overwrite or keep)
			$fb->addSubItem($fb_file);
		
			$fb_date = new ilRadioGroupInputGUI($lng->txt("exc_global_feedback_file_date"), "fb_date");
			$fb_date->setRequired(true);
			$fb_date->addOption(new ilRadioOption($lng->txt("exc_global_feedback_file_date_deadline"), ilExAssignment::FEEDBACK_DATE_DEADLINE));
			$fb_date->addOption(new ilRadioOption($lng->txt("exc_global_feedback_file_date_upload"), ilExAssignment::FEEDBACK_DATE_SUBMISSION));

			//Extra radio option with date selection
			$fb_date_custom_date = new ilDateTimeInputGUI($lng->txt("date"),"fb_date_custom");
			$fb_date_custom_date->setRequired(true);
			$fb_date_custom_date->setShowTime(true);
			$fb_date_custom_option = new ilRadioOption($lng->txt("exc_global_feedback_file_after_date"), ilExAssignment::FEEDBACK_DATE_CUSTOM);
			$fb_date_custom_option->addSubItem($fb_date_custom_date);
			$fb_date->addOption($fb_date_custom_option);


		$fb->addSubItem($fb_date);

			$fb_cron = new ilCheckboxInputGUI($lng->txt("exc_global_feedback_file_cron"), "fb_cron");
			$fb_cron->setInfo($lng->txt("exc_global_feedback_file_cron_info"));
			$fb->addSubItem($fb_cron);
		

		require_once './Customizing/global/plugins/Services/UIComponent/UserInterfaceHook/PlagScanExercise/classes/form/class.ilPlagScanFormSection.php';
        $plag_scan_additions = new ilPlagScanFormSection();
        $plag_scan_additions->addPlagScanConfig($form);

		if ($a_mode == "create")
		{
			$form->addCommandButton("saveAssignment", $lng->txt("save"));
			$form->addCommandButton("listAssignments", $lng->txt("cancel"));
		}
		else
		{
			$form->addCommandButton("updateAssignment", $lng->txt("save"));
			$form->addCommandButton("listAssignments", $lng->txt("cancel"));
		}
		
		return $form;
	}
}
